polimorfo.datasets package
==========================

Submodules
----------

polimorfo.datasets.coco module
------------------------------

.. automodule:: polimorfo.datasets.coco
    :members:
    :undoc-members:
    :show-inheritance:

polimorfo.datasets.utils module
-------------------------------

.. automodule:: polimorfo.datasets.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: polimorfo.datasets
    :members:
    :undoc-members:
    :show-inheritance:
